/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EZBManageableContainer.java 579 2006-06-05 12:27:05Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.api;

import java.io.File;

/**
 * Manageable interface for {@link EZBContainer}.
 * @author Guillaume Sauthier
 */
public interface EZBManageableContainer {

    /**
     * Gets the id of this container.
     * @return string id.
     */
    String getId();

    /**
     * Gets the name of this container.
     * @return the name.
     */
    String getName();

    /**
     * Start this container.
     * @throws EZBContainerException if the start fails.
     */
    void start() throws EZBContainerException;

    /**
     * Stop this container.
     */
    void stop();

    /**
     * Gets the archive used by this container. It can be a .jar file or a directory.
     * @return the archive.
     */
    File getArchive();

    /**
     * Check if the container is available or not.
     * @return true if the container is available.
     */
    boolean isAvailable();

}
