/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsTransactionInterceptor.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.transaction.interceptors;

import javax.transaction.TransactionManager;

import org.objectweb.easybeans.api.EasyBeansInterceptor;
import org.objectweb.easybeans.api.EasyBeansInvocationContext;
import org.objectweb.easybeans.transaction.JTransactionManager;

/**
 * Defines an abstract interceptor for transaction with common code used by all transaction interceptors.
 * @author Florent Benoit
 */
public abstract class AbsTransactionInterceptor implements EasyBeansInterceptor{

    /**
     * Transaction manager.
     */
    private TransactionManager transactionManager = null;

    /**
     * Constructor.<br>
     * Acquire the transaction manager.
     */
    public AbsTransactionInterceptor() {
        this.transactionManager = JTransactionManager.getTransactionManager();
    }


    /**
     * Defines the code used by the transaction interceptor on a given method.
     * @param invocationContext context with useful attributes on the current
     *        invocation
     * @return result of the next invocation (to chain interceptors)
     * @throws Exception if interceptor fails
     */
    public abstract Object intercept(final EasyBeansInvocationContext invocationContext) throws Exception;


    /**
     * Gets the transaction manager.
     * @return TM.
     */
    public TransactionManager getTransactionManager() {
        return transactionManager;
    }

}
