/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JClassInterceptor.java 687 2006-06-19 14:59:24Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.annotations;


/**
 * This class defines a Bean interceptor with the name of the class and the
 * method which is the interceptor.
 * @author Florent Benoit
 */
public class JClassInterceptor {

    /**
     * String name of the class (internal name) where is the interceptor.
     */
    private String className = null;

    /**
     * Method with &#64;{@link javax.interceptor.AroundInvoke} annotation.
     */
    private JMethod jMethod = null;

    /**
     * Constructor.
     * @param className String name of the class (internal name).
     * @param jMethod the method with aroundInvoke annotation.
     */
    public JClassInterceptor(final String className, final JMethod jMethod) {
        this.className = className;
        this.jMethod = jMethod;
    }

    /**
     * @return class (internal name) where is the interceptor.
     */
    public String getClassName() {
        return className;
    }

    /**
     * @return Method with &#64;{@link javax.interceptor.AroundInvoke} annotation
     */
    public JMethod getJMethod() {
        return jMethod;
    }

    /**
     * Equals method.
     * @param another object to compare.
     * @return true if the objects are the same.
     */
    @Override
    public boolean equals(final Object another) {
        if (!(another instanceof JClassInterceptor)) {
            return false;
        }
        JClassInterceptor anotherItcp = (JClassInterceptor) another;
        return (anotherItcp.className.equals(className) && anotherItcp.jMethod.equals(jMethod));
    }

    /**
     * @return hashCode of the object.
     */
    @Override
    public int hashCode() {
        return className.hashCode() + jMethod.hashCode();
    }

}
