/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Pool.java 688 2006-06-19 16:50:52Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.pool;

/**
 * Defines a common pool interface used to manage objects.
 * @param <InstanceType> the type of the object that are managed by the pool
 *        (could be EasyBeansSLSB, etc.)
 * @param <Clue> a clue to retrieve a specific instance in the pool
 * @author Florent Benoit
 */
public interface Pool<InstanceType, Clue> extends PoolAttributes {

    /**
     * Gets an object from the pool.
     * @return an instance of an object with type Type.
     * @throws PoolException if instance cannot be returned.
     */
    InstanceType get() throws PoolException;

    /**
     * Gets an object by using a specific hint.
     * @param clue attribute used to retrieve a given instance
     * @return a specific instance of the resource.
     * @throws PoolException if instance cannot be returned.
     */
    InstanceType get(Clue clue) throws PoolException;

    /**
     * Puts back the instance in the pool so it can be reused.
     * @param instance which will be put back in the pool.
     * @throws PoolException if instance is not released.
     */
    void release(InstanceType instance) throws PoolException;

    /**
     * Discard the instance which is in the pool.
     * @param instance which will be discarded.
     * @throws PoolException if instance is not discarded.
     */
    void discard(InstanceType instance) throws PoolException;

    /**
     * Start the pool.<br>
     * It could create initial instances if specified.
     * @throws PoolException if initialization fails
     */
    void start() throws PoolException;

    /**
     * Stop this pool.
     * @throws PoolException if destroy fails
     */
    void stop() throws PoolException;
}
