/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EBaseTimeoutCallbackResourceManager00.java 524 2006-05-28 19:53:40Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.base;

import javax.annotation.Resource;
import javax.ejb.Timeout;
import javax.ejb.Timer;
import javax.ejb.TimerService;
import javax.sql.DataSource;

import org.objectweb.easybeans.tests.common.db.TableManager;
import org.objectweb.easybeans.tests.common.resources.Watcher;

/**
 * Used as base of beans to test timeout callback.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
@Resource(name = "jdbc/jdbc_1", mappedName = "jdbc_1", type = javax.sql.DataSource.class)
public class EBaseTimeoutCallbackResourceManager00 implements ItfTimeoutCallback00 {

    /**
     * TimerService.
     */
    @Resource
    private TimerService ts;

    /**
     * Injected DataSource.
     */
    @Resource(name = "jdbc/jdbc_1")
    private DataSource ds;

    /**
     * Timeout callback that access the session context.
     * @param timer timer with information.
     */
    @Timeout
    public void timeout(final Timer timer) {
        try {
            // Resource Manager
            TableManager resTest = new TableManager(ds);
            resTest.test("tmpTable" + resTest.hashCode());

        } catch (Exception e) {
            Watcher.getInstance().setException(e);
        }
    }

    /**
     * Starts a timer and when this timer ends the timeout callback method access the Resource Manager.
     * @param duration timer duration
     */
    public void startTimer(final int duration) {
        ts.createTimer(DURATION, "");
    }

}
