/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: BasePctxLifeCMTTester00.java 546 2006-05-30 13:12:22Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.base.persistencectxlife;

import static org.objectweb.easybeans.tests.common.helper.EJBHelper.getBeanRemoteInstance;
import static org.objectweb.easybeans.tests.common.helper.TransactionHelper.getInternalUserTransaction;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertTrue;

import javax.transaction.UserTransaction;

import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.persistencectxlife.SFSBPCtxLifeCMT00;

/**
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 *
 */
public class BasePctxLifeCMTTester00 {

    /**
     * Bean.
     */
    private ItfPCtxLifetime00 bean00;

    /**
     * UserTransaction.
     */
    private UserTransaction utx;

    /**
     * Sets the bean used in the tests.
     * @param bean instance
     * @throws Exception if a problem occurs.
     */
    public void setBean(final ItfPCtxLifetime00 bean) throws Exception{
        bean00 = bean;
        bean00.initEntityManager();
        utx = getInternalUserTransaction();
    }

    /**
     * Tests if an entity manager with a stateful can manage a transaction-scoped persistence context.
     * @throws Exception if a problem occurs.
     */
    public void test00() throws Exception{
        utx.begin();

        bean00.createCheckEntity00();

        utx.rollback();

        assertFalse(bean00.existsEntity(), "The bean must not exists, the transaction was rollbacked.");
    }

    /**
     * Tests if an entity manager with a stateful can manage a transaction-scoped persistence context.
     * @throws Exception if a problem occurs.
     */
    public void test01() throws Exception{
        utx.begin();

        bean00.createCheckEntity00();

        utx.commit();

        //Checks if the bean is detached, the transaction was finished.
        bean00.checkDetached();
    }

    /**
     * Tests if an entity manager with a stateful can manage a transaction-scoped persistence context.
     * @throws Exception if a problem occurs.
     */
    public void test02() throws Exception{
        utx.begin();

        bean00.createCheckEntity00();

        //Checks if the bean is managed, the transaction is open.
        bean00.checkManaged();

        utx.rollback();
    }

    /**
     * Tests if an entity manager with a stateful can manage a transaction-scoped persistence context.
     * @throws Exception if a problem occurs.
     */
    public void test03() throws Exception{
        bean00.createCheckEntity00();

        assertTrue(bean00.existsEntity(), "The bean must exists.");

        bean00.checkDetached();
    }

    /**
     * Tests if an entity manager with a stateful can manage a transaction-scoped persistence context.
     * @throws Exception if a problem occurs.
     */
    public void test04() throws Exception{
        bean00.createCheckEntity01();
        bean00.checkDetached();
    }

    /**
     * Removes old entity.
     * @throws Exception if a problem occurs
     */
    public void tearDown() throws Exception{
        ItfPCtxLifetime00 beanRemove = getBeanRemoteInstance(SFSBPCtxLifeCMT00.class, ItfPCtxLifetime00.class);
        beanRemove.initEntityManager();
        beanRemove.removeEntity();
    }
}
