/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SLSBInvocationTest01.java 547 2006-05-30 13:50:43Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged;

import javax.ejb.Remote;
import javax.ejb.Stateless;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;

import org.objectweb.easybeans.tests.common.ejbs.base.ItfInvocation00;
import org.objectweb.easybeans.tests.common.helper.InvocationContextHelper;
import org.objectweb.easybeans.tests.common.interceptors.invocationcontext.BeanDescriptor;

/**
 * This bean is used to manipulate the invocation context object.
 * @author Eduardo Studzinski E. de Castro
 * @author Gisele Pinheiro Souza
 */
@Stateless
@Remote(ItfInvocation00.class)
public class SLSBInvocationTest01 implements ItfInvocation00 {

    /**
     * Gets a boolean value.
     * @param beanDescriptor bean descriptor
     * @return true, the interceptor changes the result.
     */
    public boolean getBool(final BeanDescriptor beanDescriptor) {
        return false;
    }

    /**
     * Interceptor that checks the invocation context object, it's compares the bean descriptor.
     * <li>The first parameter of the intercepted method must be a BeanDescriptor.</li>
     * @param ic contains attributes of invocation
     * @return method's invocation result
     * @throws Exception if invocation fails
     */
    @SuppressWarnings("unused")
    @AroundInvoke
    private Object checkDescriptor(final InvocationContext ic) throws Exception{
        return InvocationContextHelper.checkBeanDescriptor(ic);
    }

}
