/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: PostConstructCatchException00.java 588 2006-06-05 13:50:46Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.interceptors.lifecycle.postconstruct;

import javax.annotation.PostConstruct;
import javax.interceptor.InvocationContext;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;
import org.objectweb.easybeans.tests.common.exception.CatchedException;
import org.objectweb.easybeans.tests.common.exception.IllegalException;


/**
 * PostConstruct is used to get an IllegalException.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 *
 */
public class PostConstructCatchException00 {

    /**
     * Log helper.
     */
    private JLog logger = JLogFactory.getLog(PostConstructCatchException00.class);

    /**
     * Catches an CatchedException from another interceptor.
     * @param ic context
     */
    @PostConstruct
    public void catchException(final InvocationContext ic){
        logger.debug("PostConstruct started.");
        try{
            logger.debug("Calling proceed.");
            ic.proceed();
        }catch(IllegalException e){
            logger.debug("IllegalException.");
            throw new CatchedException("PostConstruct callback was invoked.", e);
        }catch(Exception e){
            logger.debug("IllegalStateException.");
            throw new IllegalStateException("The expected exception was not thrown.");
        }
    }
}
