/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestSimpleEnvironmentEntryFieldInjection.java 435 2006-05-09 12:51:58Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.environment.reference.simpleentry;

import static org.objectweb.easybeans.tests.common.enhancer.ClassesEnhancer.EXT_CLASS;
import static org.objectweb.easybeans.tests.common.enhancer.ClassesEnhancer.enhanceNewClassLoader;
import static org.objectweb.easybeans.tests.common.helper.EJBHelper.getBeanRemoteInstance;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.objectweb.easybeans.tests.common.ejbs.base.ItfOneMethod01;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntryByDescriptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.simpleentry.SLSBSimpleEnvEntryFieldInjection00;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.simpleentry.SLSBSimpleEnvEntryByDescriptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.simpleentry.wrongspecification.SLSBFinalFieldEntry;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.simpleentry.wrongspecification.SLSBStaticEntry;
import org.objectweb.easybeans.tests.common.enhancer.ClassesEnhancer.TYPE;
import org.testng.annotations.Configuration;
import org.testng.annotations.ExpectedExceptions;
import org.testng.annotations.Test;

/**
 * Verifies if the simple environment entries injection is following the JSR220.
 * The items covered in this test are: 15.4
 * @reference JSR220-PROPOSED FINAL
 * @requirement Application Server must be running; the bean
 *              org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.simpleentry.*
 *              must be deployed.
 * @setup gets the reference of the bean
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class TestSimpleEnvironmentEntryFieldInjection {

    /**
     * Bean used in tests.
     */
    private ItfSimpleEnvEntry bean;

    /**
     * Bean used in tests.
     */
    private ItfSimpleEnvEntryByDescriptor beanInjectionByDescriptor;

    /**
     * Gets bean instances used in the tests.
     * @throws Exception if there is a problem with the bean initialization.
     */
    @Configuration(beforeTestMethod = true)
    public void startUp() throws Exception {
        bean = getBeanRemoteInstance(SLSBSimpleEnvEntryFieldInjection00.class, ItfSimpleEnvEntry.class);
        beanInjectionByDescriptor = getBeanRemoteInstance(SLSBSimpleEnvEntryByDescriptor.class,
                ItfSimpleEnvEntryByDescriptor.class);
    }

    /**
     * Tests if a string value was correctly injected.
     * @input -
     * @output -
     */
    @Test
    public void testString00() {
        bean.checkString00();
    }

    /**
     * Tests if a character value was correctly injected.
     * @input -
     * @output -
     */
    @Test
    public void testCharacter00() {
        bean.checkCharacter00();
    }

    /**
     * Tests if an integer value was correctly injected.
     * @input -
     * @output -
     */
    @Test
    public void testInteger00() {
        bean.checkInteger00();
    }

    /**
     * Tests if a boolean value was correctly injected.
     * @input -
     * @output -
     */
    @Test
    public void testBoolean00() {
        bean.checkBoolean00();
    }

    /**
     * Tests if a double value was correctly injected.
     * @input -
     * @output -
     */
    @Test
    public void testDouble00() {
        bean.checkDouble00();
    }

    /**
     * Tests if a byte value was correctly injected.
     * @input -
     * @output -
     */
    @Test
    public void testByte00() {
        bean.checkByte00();
    }

    /**
     * Tests if a short value was correctly injected.
     * @input -
     * @output -
     */
    @Test
    public void testShort00() {
        bean.checkByte00();
    }

    /**
     * Tests if a byte value was correctly injected.
     * @input -
     * @output -
     */
    @Test
    public void testLong00() {
        bean.checkLong00();
    }

    /**
     * Tests if a float value was correctly injected.
     * @input -
     * @output -
     */
    @Test
    public void testFloat00() {
        bean.checkFloat00();
    }

    /**
     * Tests if a variable continues with its default value when the
     * evn-entry-value is not specified.
     * @input -
     * @output -
     */
    @Test
    public void testNotOverride00() {
        beanInjectionByDescriptor.checkNotOverride00();
    }

    /**
     * Tests if injection by deployment descriptor using injection-target tag is working properly.
     * @input -
     * @output -
     */
    @Test
    public void testInjectionByDeploymentDescriptor00() {
        beanInjectionByDescriptor.checkStringInjection00();
    }

    /**
     * This test should cause an enhancer exception. The &#64;Resource is annoted in a static field, it is denied by the
     *           specification.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"})
    @ExpectedExceptions({IllegalStateException.class})
    public void testWrongSpec00() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(ItfOneMethod01.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(SLSBStaticEntry.class.getName().replace(".", File.separator) + EXT_CLASS);
        enhanceNewClassLoader(lstFiles, TYPE.ALL);
    }

    /**
     * This test should cause an enhancer exception. The &#64;Resource is annoted in a final field, it is denied by the
     *           specification.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"})
    @ExpectedExceptions({IllegalStateException.class})
    public void testWrongSpec01() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(ItfOneMethod01.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(SLSBFinalFieldEntry.class.getName().replace(".", File.separator) + EXT_CLASS);
        enhanceNewClassLoader(lstFiles, TYPE.ALL);
    }

}
