/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestMDBInvocationOrder.java 725 2006-06-22 13:49:25Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.interceptors.business.messagedriven.conteinermanaged;

import static org.objectweb.easybeans.tests.common.ejbs.entity.callbacklogger.CallbackType.AROUND_INVOKE;
import static org.objectweb.easybeans.tests.common.ejbs.entity.callbacklogger.OperationType.UNDEFINED;
import static org.objectweb.easybeans.tests.common.helper.EJBHelper.getBeanRemoteInstance;

import java.util.ArrayList;
import java.util.List;

import org.objectweb.easybeans.tests.common.ejbs.mdb.containermanaged.interceptor.MDBInvocationOrder00;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.callbacklogger.ItfCallbackLoggerAccess;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.callbacklogger.SLSBCallbackLoggerAccess;
import org.objectweb.easybeans.tests.common.jms.JMSManager;
import org.testng.annotations.Configuration;
import org.testng.annotations.Test;


/**
 * Tests the interceptor invocation order for Message-Driven Beans.
 * @reference JSR220-PROPOSED FINAL - Interceptors - Business Methods Invocation Order
 * @requirement MDB:
 *              org.objectweb.easybeans.tests.common.ejbs.mdb.containermanaged.interceptor.MDBInvocationOrder00
 * @setup gets the reference of SFSBAccessInterceptorTest01
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class TestMDBInvocationOrder {

    /**
     * JMS Manager.
     */
    private JMSManager jmsQueue;

    /**
     * Logger bean.
     */
    private ItfCallbackLoggerAccess beanLogger;

    /**
     * Creates the JMS manager.
     * @throws Exception if there is a problem.
     */
    @Configuration(beforeTestClass = true)
    public void startUp00() throws Exception {
        jmsQueue = new JMSManager(JMSManager.DEFAULT_QUEUE_CONNECTION_FACTORY, JMSManager.DEFAULT_QUEUE);
        beanLogger = getBeanRemoteInstance(SLSBCallbackLoggerAccess.class, ItfCallbackLoggerAccess.class);
    }

    /**
     * Gets the bean logger instance and clears previous tests information.
     * @throws Exception if there is a problem with the bean initialization.
     */
    @Configuration(beforeTestMethod = true)
    public void startUp01() throws Exception {
        beanLogger.deleteAll();
    }

    /**
     * Verifies if business interceptors can be used with MDBs.
     * @input a message
     * @output a logged onMessage() event
     * @throws Exception if a problem occurs.
     */
    @Test
    public void testQueue01() throws Exception {
        jmsQueue.sendControlMessage(MDBInvocationOrder00.MESSAGE_TYPE, UNDEFINED);

        // Verifies if the message was received
        List<String> arEvent = new ArrayList<String>();

        arEvent.add(MDBInvocationOrder00.class.getName());

        beanLogger.verifyCallbackOrder(MDBInvocationOrder00.class, AROUND_INVOKE, arEvent.toArray(new String[0]));
    }

    /**
     * Clears logs.
     * @throws Exception if a problem occurs.
     */
    @Configuration(afterTestMethod = true)
    public void tearDown() throws Exception {
        beanLogger.deleteAll();
    }

    /**
     * Clears logs.
     * @throws Exception if a problem occurs.
     */
    @Configuration(afterTestClass = true)
    public void tearDownClass() throws Exception {
        jmsQueue.close();
    }
}
