/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestPersistenceLifetimeCMExtended02.java 546 2006-05-30 13:12:22Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.persistence.lifetime;

import static org.objectweb.easybeans.tests.common.helper.EJBHelper.getBeanRemoteInstance;

import org.objectweb.easybeans.tests.common.ejbs.base.persistencectxlife.ItfPCtxLifeCMETest00;
import org.objectweb.easybeans.tests.common.ejbs.stateful.beanmanaged.persistencectxlife.SLSBBeanManagedPCtxLifeCMETest00;
import org.testng.annotations.Configuration;
import org.testng.annotations.Test;

/**
 * Tests container-managed extended-scoped persistence context.
 * @reference JSR220 - Persistence API - FINAL DRAFT - 5.6.2
 * @requirement Application Server must be running; the package
 *              org.objectweb.easybeans.tests.common.ejbs.stateful.beanmanaged.persistencectxlife
 *              must be deployed
 * @setup gets the reference of the bean.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class TestPersistenceLifetimeCMExtended02 {

    /**
     * Bean.
     */
    private ItfPCtxLifeCMETest00 bean;

    /**
     * Gets bean instances used in the tests.
     * @throws Exception if there is a problem with the bean initialization.
     */
    @Configuration(beforeTestMethod = true)
    public void startUp() throws Exception {
        bean = getBeanRemoteInstance(SLSBBeanManagedPCtxLifeCMETest00.class, ItfPCtxLifeCMETest00.class);
    }

    /**
     * Tests if an entity manager with a stateful can manage a
     * extended-scoped persistence context. The stateful creates a transaction
     * that must be propagated during two beans, after the commit,
     * it is check if the context is still managed.
     * @throws Exception if a problem occurs.
     */
    @Test
    public void test00() throws Exception {
        bean.create();
        bean.check();
    }
}
