/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestRequiredExceptionRemoteSFSB.java 439 2006-05-10 11:21:09Z pinheirg $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.transaction.containermanaged.stateful;

import java.sql.SQLException;

import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBContainerTransactionRequiredApp;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBContainerTransactionRequiredRollback;
import org.objectweb.easybeans.tests.common.ejbs.stateful.containermanaged.SFSBContainerTransactionRequiredRuntime;
import org.objectweb.easybeans.tests.transaction.containermanaged.base.TestRequiredException;
import org.testng.annotations.Configuration;
import org.testng.annotations.ExpectedExceptions;
import org.testng.annotations.Test;

/**
 * Verifies if the container-managed transaction in the session bean is
 * following the JSR220. The container must handle the different types of
 * exception in the transaction context. The items covered in this test are:
 * 13.3
 * @reference JSR220-PROPOSED FINAL
 * @requirement Application Server must be running; the bean .
 *              SFSBContainerTransactionRequiredApp,
 *              SFSBContainerTransactionRequiredRollback and
 *              SFSBContainerTransactionRequiredRuntime must be deployed for
 *              testing stateful session bean.
 * @setup gets the reference of the bean and binds the databases specified in
 *        the EmbeddedTest.
 * @author Gisele Pinheiro Souza
 * @author Eduardo Studzinski Estima de Castro
 */
public class TestRequiredExceptionRemoteSFSB extends TestRequiredException {

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestRequiredException
     * @throws Exception if an error during the test occurs.
     */
    @Test(groups = {"runtime exception tests"})
    @Override
    public void testCallOtherBeanNotSup() throws Exception {
        super.testCallOtherBeanNotSup();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestRequiredException
     * @throws Exception if an error during the test occurs.
     */
    @Test(groups = {"runtime exception tests"})
    @Override
    public void testCallOtherBeanReq() throws Exception {
        super.testCallOtherBeanReq();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     * @throws Exception if an error during the test occurs.
     */
    @Test(groups = {"application exception tests"})
    @Override
    @ExpectedExceptions(value = SQLException.class)
    public void testNotUsingClientTransWithAppException() throws Exception {
        super.testNotUsingClientTransWithAppException();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     * @throws Exception if an error during the test occurs.
     */
    @Test(groups = {"application rollback exception tests"})
    @Override
    @ExpectedExceptions(value = SQLException.class)
    public void testNotUsingClientTransWithAppRollbackException() throws Exception {
        super.testNotUsingClientTransWithAppRollbackException();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     * @throws Exception if an error during the test occurs.
     */
    @Test(groups = {"runtime exception tests"})
    @Override
    @ExpectedExceptions(value = SQLException.class)
    public void testNotUsingClientTransWithRuntimeException() throws Exception {
        super.testNotUsingClientTransWithRuntimeException();
    }

    /**
     * Creates a bean used during the test before each method.
     * @throws Exception if a lookup error occurs.
     */
    @Configuration(beforeTestMethod = true, groups = "application exception tests")
    public void createBeanApp() throws Exception {
        super.createBeanApp(SFSBContainerTransactionRequiredApp.class);
    }

    /**
     * Creates a bean used during the test before each method.
     * @throws Exception if a lookup error occurs.
     */
    @Configuration(beforeTestMethod = true, groups = "application rollback exception tests")
    public void createBeanRollback() throws Exception {
        super.createBeanRollback(SFSBContainerTransactionRequiredRollback.class);
    }

    /**
     * Creates a bean used during the test before each method.
     * @throws Exception if a lookup error occurs.
     */
    @Configuration(beforeTestMethod = true, groups = "runtime exception tests")
    public void createBeanRuntime() throws Exception {
        super.createBeanRuntime(SFSBContainerTransactionRequiredRuntime.class);
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     */
    @Configuration(beforeTestMethod = true)
    @Override
    public void deleteTable() {
        super.deleteTable();
    }

    /**
     * @see org.objectweb.easybeans.tests.transaction.containermanaged.base.TestContainerTransactionException
     * @throws Exception if an error during the initialization occurs.
     */
    @Configuration(beforeTestClass = true)
    @Override
    public void setup() throws Exception {
        super.setup();
    }

}
